@@ -10,10 +10,13 @@ class FileBrowserFile(models.Model):
     )
     
     file_type = models.CharField(max_length=3, choices=FILE_TYPES)
-    uploaded_file = models.FileField(upload_to='mce_filebrowser/%Y/%m/%d',
-                                     verbose_name = _('File / Image'))
-    create_date = models.DateTimeField(auto_now_add=True,
-                                       verbose_name=_('Create date'))
+    uploaded_file = models.FileField(
+        upload_to='mce_filebrowser/%Y/%m/%d',
+        verbose_name = _('File / Image')
+    )
+    create_date = models.DateTimeField(
+        auto_now_add=True, verbose_name=_('Create date')
+    )
     
     def __unicode__(self):
-        return u'{0}'.format(self.uploaded_file.name)
+        return u'%s' % self.uploaded_file.name
