@@ -1,7 +1,4 @@
-try:
-    from django.conf.urls.defaults import patterns, url
-except ImportError:
-    from django.conf.urls import patterns, url
+from django.conf.urls.defaults import *
 
 from mce_filebrowser import views
 
@@ -27,4 +24,4 @@ urlpatterns = patterns('',
         {'file_type': 'doc'},
         name='mce-filebrowser-remove-document'
     )
-)
+)
\ No newline at end of file
